# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.cuentas_de_beneficiarios_spid_api import CuentasDeBeneficiariosSPIDApi  # noqa: E501
from wire4_client.rest import ApiException


class TestCuentasDeBeneficiariosSPIDApi(unittest.TestCase):
    """CuentasDeBeneficiariosSPIDApi unit test stubs"""

    def setUp(self):
        self.api = api.cuentas_de_beneficiarios_spid_api.CuentasDeBeneficiariosSPIDApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_spid_beneficiaries_for_account(self):
        """Test case for get_spid_beneficiaries_for_account

        Consulta los beneficiarios SPID registrados  # noqa: E501
        """
        pass

    def test_pre_register_accounts_using_post1(self):
        """Test case for pre_register_accounts_using_post1

        Pre-registro de cuentas de beneficiarios SPID®  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.comprobante_electrnico_de_pago__cep_api import ComprobanteElectrnicoDePagoCEPApi  # noqa: E501
from wire4_client.rest import ApiException


class TestComprobanteElectrnicoDePagoCEPApi(unittest.TestCase):
    """ComprobanteElectrnicoDePagoCEPApi unit test stubs"""

    def setUp(self):
        self.api = api.comprobante_electrnico_de_pago__cep_api.ComprobanteElectrnicoDePagoCEPApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_obtain_transaction_cep_using_post(self):
        """Test case for obtain_transaction_cep_using_post

        Consulta de CEP  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.beneficiary_institution import BeneficiaryInstitution  # noqa: F401,E501
from wire4_client.models.institution import Institution  # noqa: F401,E501
from wire4_client.models.person import Person  # noqa: F401,E501


class AccountReassigned(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_limit': 'float',
        'bank': 'Institution',
        'beneficiary_account': 'str',
        'currency_code': 'str',
        'email': 'list[str]',
        'institution': 'BeneficiaryInstitution',
        'kind_of_relationship': 'str',
        'numeric_reference_spei': 'str',
        'payment_concept_spei': 'str',
        'person': 'Person',
        'register_date': 'datetime',
        'relationship': 'str',
        'rfc': 'str',
        'status': 'str'
    }

    attribute_map = {
        'amount_limit': 'amount_limit',
        'bank': 'bank',
        'beneficiary_account': 'beneficiary_account',
        'currency_code': 'currency_code',
        'email': 'email',
        'institution': 'institution',
        'kind_of_relationship': 'kind_of_relationship',
        'numeric_reference_spei': 'numeric_reference_spei',
        'payment_concept_spei': 'payment_concept_spei',
        'person': 'person',
        'register_date': 'register_date',
        'relationship': 'relationship',
        'rfc': 'rfc',
        'status': 'status'
    }

    def __init__(self, amount_limit=None, bank=None, beneficiary_account=None, currency_code=None, email=None, institution=None, kind_of_relationship=None, numeric_reference_spei=None, payment_concept_spei=None, person=None, register_date=None, relationship=None, rfc=None, status=None):  # noqa: E501
        """AccountReassigned - a model defined in Swagger"""  # noqa: E501
        self._amount_limit = None
        self._bank = None
        self._beneficiary_account = None
        self._currency_code = None
        self._email = None
        self._institution = None
        self._kind_of_relationship = None
        self._numeric_reference_spei = None
        self._payment_concept_spei = None
        self._person = None
        self._register_date = None
        self._relationship = None
        self._rfc = None
        self._status = None
        self.discriminator = None
        self.amount_limit = amount_limit
        if bank is not None:
            self.bank = bank
        self.beneficiary_account = beneficiary_account
        if currency_code is not None:
            self.currency_code = currency_code
        if email is not None:
            self.email = email
        if institution is not None:
            self.institution = institution
        self.kind_of_relationship = kind_of_relationship
        if numeric_reference_spei is not None:
            self.numeric_reference_spei = numeric_reference_spei
        if payment_concept_spei is not None:
            self.payment_concept_spei = payment_concept_spei
        if person is not None:
            self.person = person
        if register_date is not None:
            self.register_date = register_date
        self.relationship = relationship
        self.rfc = rfc
        if status is not None:
            self.status = status

    @property
    def amount_limit(self):
        """Gets the amount_limit of this AccountReassigned.  # noqa: E501

        Es el monto límite permitido que se registra para la cuenta. Por ejemplo 1000.00.  # noqa: E501

        :return: The amount_limit of this AccountReassigned.  # noqa: E501
        :rtype: float
        """
        return self._amount_limit

    @amount_limit.setter
    def amount_limit(self, amount_limit):
        """Sets the amount_limit of this AccountReassigned.

        Es el monto límite permitido que se registra para la cuenta. Por ejemplo 1000.00.  # noqa: E501

        :param amount_limit: The amount_limit of this AccountReassigned.  # noqa: E501
        :type: float
        """
        if amount_limit is None:
            raise ValueError("Invalid value for `amount_limit`, must not be `None`")  # noqa: E501

        self._amount_limit = amount_limit

    @property
    def bank(self):
        """Gets the bank of this AccountReassigned.  # noqa: E501


        :return: The bank of this AccountReassigned.  # noqa: E501
        :rtype: Institution
        """
        return self._bank

    @bank.setter
    def bank(self, bank):
        """Sets the bank of this AccountReassigned.


        :param bank: The bank of this AccountReassigned.  # noqa: E501
        :type: Institution
        """

        self._bank = bank

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this AccountReassigned.  # noqa: E501

        Es la cuenta del beneficiario, podría ser teléfono celular (se valida que sea de 10 dígitos), Tarjeta de débito (TDD, se valida que sea de 16 dígitos) o cuenta CLABE (se valida que sea de 18 dígitos). <br/><br/>Por ejemplo Teléfono celular: 5525072600, TDD: 4323 1234 5678 9123, CLABE: 032180000118359719.  # noqa: E501

        :return: The beneficiary_account of this AccountReassigned.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this AccountReassigned.

        Es la cuenta del beneficiario, podría ser teléfono celular (se valida que sea de 10 dígitos), Tarjeta de débito (TDD, se valida que sea de 16 dígitos) o cuenta CLABE (se valida que sea de 18 dígitos). <br/><br/>Por ejemplo Teléfono celular: 5525072600, TDD: 4323 1234 5678 9123, CLABE: 032180000118359719.  # noqa: E501

        :param beneficiary_account: The beneficiary_account of this AccountReassigned.  # noqa: E501
        :type: str
        """
        if beneficiary_account is None:
            raise ValueError("Invalid value for `beneficiary_account`, must not be `None`")  # noqa: E501

        self._beneficiary_account = beneficiary_account

    @property
    def currency_code(self):
        """Gets the currency_code of this AccountReassigned.  # noqa: E501

        Es el código de divisa. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.<br/><br/>Este dato es opcional, al registrar una cuenta si no se cuenta con este valor se asignará <b>MXP</b>  # noqa: E501

        :return: The currency_code of this AccountReassigned.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this AccountReassigned.

        Es el código de divisa. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.<br/><br/>Este dato es opcional, al registrar una cuenta si no se cuenta con este valor se asignará <b>MXP</b>  # noqa: E501

        :param currency_code: The currency_code of this AccountReassigned.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def email(self):
        """Gets the email of this AccountReassigned.  # noqa: E501

        Es una lista de correos electrónicos (emails). Se valida el formato de email. Este campo es opcional.  # noqa: E501

        :return: The email of this AccountReassigned.  # noqa: E501
        :rtype: list[str]
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this AccountReassigned.

        Es una lista de correos electrónicos (emails). Se valida el formato de email. Este campo es opcional.  # noqa: E501

        :param email: The email of this AccountReassigned.  # noqa: E501
        :type: list[str]
        """

        self._email = email

    @property
    def institution(self):
        """Gets the institution of this AccountReassigned.  # noqa: E501


        :return: The institution of this AccountReassigned.  # noqa: E501
        :rtype: BeneficiaryInstitution
        """
        return self._institution

    @institution.setter
    def institution(self, institution):
        """Sets the institution of this AccountReassigned.


        :param institution: The institution of this AccountReassigned.  # noqa: E501
        :type: BeneficiaryInstitution
        """

        self._institution = institution

    @property
    def kind_of_relationship(self):
        """Gets the kind_of_relationship of this AccountReassigned.  # noqa: E501

        Es el tipo de relación que se tiene con el propietario de la cuenta. Para registrar una cuenta, este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br /><br /><b>Nota:</b> <em>Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.</em>  # noqa: E501

        :return: The kind_of_relationship of this AccountReassigned.  # noqa: E501
        :rtype: str
        """
        return self._kind_of_relationship

    @kind_of_relationship.setter
    def kind_of_relationship(self, kind_of_relationship):
        """Sets the kind_of_relationship of this AccountReassigned.

        Es el tipo de relación que se tiene con el propietario de la cuenta. Para registrar una cuenta, este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br /><br /><b>Nota:</b> <em>Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.</em>  # noqa: E501

        :param kind_of_relationship: The kind_of_relationship of this AccountReassigned.  # noqa: E501
        :type: str
        """
        if kind_of_relationship is None:
            raise ValueError("Invalid value for `kind_of_relationship`, must not be `None`")  # noqa: E501

        self._kind_of_relationship = kind_of_relationship

    @property
    def numeric_reference_spei(self):
        """Gets the numeric_reference_spei of this AccountReassigned.  # noqa: E501

        Es la referencia numérica a utilizar cuando se realice una transferencia y no se especifique una referencia.  # noqa: E501

        :return: The numeric_reference_spei of this AccountReassigned.  # noqa: E501
        :rtype: str
        """
        return self._numeric_reference_spei

    @numeric_reference_spei.setter
    def numeric_reference_spei(self, numeric_reference_spei):
        """Sets the numeric_reference_spei of this AccountReassigned.

        Es la referencia numérica a utilizar cuando se realice una transferencia y no se especifique una referencia.  # noqa: E501

        :param numeric_reference_spei: The numeric_reference_spei of this AccountReassigned.  # noqa: E501
        :type: str
        """

        self._numeric_reference_spei = numeric_reference_spei

    @property
    def payment_concept_spei(self):
        """Gets the payment_concept_spei of this AccountReassigned.  # noqa: E501

        Es el concepto de pago a utilizar cuando se realice una transferencia y no se especifique un concepto  # noqa: E501

        :return: The payment_concept_spei of this AccountReassigned.  # noqa: E501
        :rtype: str
        """
        return self._payment_concept_spei

    @payment_concept_spei.setter
    def payment_concept_spei(self, payment_concept_spei):
        """Sets the payment_concept_spei of this AccountReassigned.

        Es el concepto de pago a utilizar cuando se realice una transferencia y no se especifique un concepto  # noqa: E501

        :param payment_concept_spei: The payment_concept_spei of this AccountReassigned.  # noqa: E501
        :type: str
        """

        self._payment_concept_spei = payment_concept_spei

    @property
    def person(self):
        """Gets the person of this AccountReassigned.  # noqa: E501


        :return: The person of this AccountReassigned.  # noqa: E501
        :rtype: Person
        """
        return self._person

    @person.setter
    def person(self, person):
        """Sets the person of this AccountReassigned.


        :param person: The person of this AccountReassigned.  # noqa: E501
        :type: Person
        """

        self._person = person

    @property
    def register_date(self):
        """Gets the register_date of this AccountReassigned.  # noqa: E501

        Es la fecha en la que se registró el beneficiario. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The register_date of this AccountReassigned.  # noqa: E501
        :rtype: datetime
        """
        return self._register_date

    @register_date.setter
    def register_date(self, register_date):
        """Sets the register_date of this AccountReassigned.

        Es la fecha en la que se registró el beneficiario. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param register_date: The register_date of this AccountReassigned.  # noqa: E501
        :type: datetime
        """

        self._register_date = register_date

    @property
    def relationship(self):
        """Gets the relationship of this AccountReassigned.  # noqa: E501

        Es la relación con el propietario de la cuenta, para registrar este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br/> <br/> <b>Nota:</b> Si en la respuesta de Monex, sta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :return: The relationship of this AccountReassigned.  # noqa: E501
        :rtype: str
        """
        return self._relationship

    @relationship.setter
    def relationship(self, relationship):
        """Sets the relationship of this AccountReassigned.

        Es la relación con el propietario de la cuenta, para registrar este valor se debe obtener del recurso <a href=\"#operation/getAvailableRelationshipsMonexUsingGET\">relationships.</a> <br/> <br/> <b>Nota:</b> Si en la respuesta de Monex, sta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :param relationship: The relationship of this AccountReassigned.  # noqa: E501
        :type: str
        """
        if relationship is None:
            raise ValueError("Invalid value for `relationship`, must not be `None`")  # noqa: E501

        self._relationship = relationship

    @property
    def rfc(self):
        """Gets the rfc of this AccountReassigned.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) de la persona o institución propietaria dela cuenta. <br/> <br/><b>Nota:</b> Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :return: The rfc of this AccountReassigned.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this AccountReassigned.

        Es el Registro Federal de Contribuyentes (RFC) de la persona o institución propietaria dela cuenta. <br/> <br/><b>Nota:</b> Si en la respuesta de Monex esta propiedad es nula, tampoco estará presente en esta respuesta.  # noqa: E501

        :param rfc: The rfc of this AccountReassigned.  # noqa: E501
        :type: str
        """
        if rfc is None:
            raise ValueError("Invalid value for `rfc`, must not be `None`")  # noqa: E501

        self._rfc = rfc

    @property
    def status(self):
        """Gets the status of this AccountReassigned.  # noqa: E501

        Es el estado en el que se encuentra el registo del beneficiario.<br>Los valores pueden ser:<ul style=\"font-size: 12px; font-weight: 600;\"><li>RECEIVED</li><li>DELETED</li><li>REQUEST_ERROR_BY_MONEX</li><li>REQUESTED_TO_MONEX</li><li>NOTIFIED_BY_MONEX</li><li>NOTIFIED_BY_SPEIOK<li></li>NOTIFIED_WITH_ERROR_BY_SPEIOK</li><li>PENDING</li></ul>  # noqa: E501

        :return: The status of this AccountReassigned.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AccountReassigned.

        Es el estado en el que se encuentra el registo del beneficiario.<br>Los valores pueden ser:<ul style=\"font-size: 12px; font-weight: 600;\"><li>RECEIVED</li><li>DELETED</li><li>REQUEST_ERROR_BY_MONEX</li><li>REQUESTED_TO_MONEX</li><li>NOTIFIED_BY_MONEX</li><li>NOTIFIED_BY_SPEIOK<li></li>NOTIFIED_WITH_ERROR_BY_SPEIOK</li><li>PENDING</li></ul>  # noqa: E501

        :param status: The status of this AccountReassigned.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AccountReassigned, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountReassigned):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class UserCompany(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'emails': 'list[str]',
        'legal_representative': 'bool',
        'masked_name': 'str',
        'masked_user_name': 'str',
        'name': 'str',
        'phone_numbers': 'list[str]',
        'surname_father': 'str',
        'surname_mother': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'emails': 'emails',
        'legal_representative': 'legal_representative',
        'masked_name': 'masked_name',
        'masked_user_name': 'masked_user_name',
        'name': 'name',
        'phone_numbers': 'phone_numbers',
        'surname_father': 'surname_father',
        'surname_mother': 'surname_mother',
        'user_name': 'user_name'
    }

    def __init__(self, emails=None, legal_representative=None, masked_name=None, masked_user_name=None, name=None, phone_numbers=None, surname_father=None, surname_mother=None, user_name=None):  # noqa: E501
        """UserCompany - a model defined in Swagger"""  # noqa: E501
        self._emails = None
        self._legal_representative = None
        self._masked_name = None
        self._masked_user_name = None
        self._name = None
        self._phone_numbers = None
        self._surname_father = None
        self._surname_mother = None
        self._user_name = None
        self.discriminator = None
        if emails is not None:
            self.emails = emails
        if legal_representative is not None:
            self.legal_representative = legal_representative
        if masked_name is not None:
            self.masked_name = masked_name
        if masked_user_name is not None:
            self.masked_user_name = masked_user_name
        if name is not None:
            self.name = name
        if phone_numbers is not None:
            self.phone_numbers = phone_numbers
        if surname_father is not None:
            self.surname_father = surname_father
        if surname_mother is not None:
            self.surname_mother = surname_mother
        if user_name is not None:
            self.user_name = user_name

    @property
    def emails(self):
        """Gets the emails of this UserCompany.  # noqa: E501

        Una lista de los correos del usuario  # noqa: E501

        :return: The emails of this UserCompany.  # noqa: E501
        :rtype: list[str]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this UserCompany.

        Una lista de los correos del usuario  # noqa: E501

        :param emails: The emails of this UserCompany.  # noqa: E501
        :type: list[str]
        """

        self._emails = emails

    @property
    def legal_representative(self):
        """Gets the legal_representative of this UserCompany.  # noqa: E501

        Indica sí es representate legal  # noqa: E501

        :return: The legal_representative of this UserCompany.  # noqa: E501
        :rtype: bool
        """
        return self._legal_representative

    @legal_representative.setter
    def legal_representative(self, legal_representative):
        """Sets the legal_representative of this UserCompany.

        Indica sí es representate legal  # noqa: E501

        :param legal_representative: The legal_representative of this UserCompany.  # noqa: E501
        :type: bool
        """

        self._legal_representative = legal_representative

    @property
    def masked_name(self):
        """Gets the masked_name of this UserCompany.  # noqa: E501

        El nombre del usuario enmascarado  # noqa: E501

        :return: The masked_name of this UserCompany.  # noqa: E501
        :rtype: str
        """
        return self._masked_name

    @masked_name.setter
    def masked_name(self, masked_name):
        """Sets the masked_name of this UserCompany.

        El nombre del usuario enmascarado  # noqa: E501

        :param masked_name: The masked_name of this UserCompany.  # noqa: E501
        :type: str
        """

        self._masked_name = masked_name

    @property
    def masked_user_name(self):
        """Gets the masked_user_name of this UserCompany.  # noqa: E501

        El nombre del usuario de acceso enmascarado  # noqa: E501

        :return: The masked_user_name of this UserCompany.  # noqa: E501
        :rtype: str
        """
        return self._masked_user_name

    @masked_user_name.setter
    def masked_user_name(self, masked_user_name):
        """Sets the masked_user_name of this UserCompany.

        El nombre del usuario de acceso enmascarado  # noqa: E501

        :param masked_user_name: The masked_user_name of this UserCompany.  # noqa: E501
        :type: str
        """

        self._masked_user_name = masked_user_name

    @property
    def name(self):
        """Gets the name of this UserCompany.  # noqa: E501

        El nombre del usuario  # noqa: E501

        :return: The name of this UserCompany.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserCompany.

        El nombre del usuario  # noqa: E501

        :param name: The name of this UserCompany.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def phone_numbers(self):
        """Gets the phone_numbers of this UserCompany.  # noqa: E501

        Una lista de los teléfonos del usuario  # noqa: E501

        :return: The phone_numbers of this UserCompany.  # noqa: E501
        :rtype: list[str]
        """
        return self._phone_numbers

    @phone_numbers.setter
    def phone_numbers(self, phone_numbers):
        """Sets the phone_numbers of this UserCompany.

        Una lista de los teléfonos del usuario  # noqa: E501

        :param phone_numbers: The phone_numbers of this UserCompany.  # noqa: E501
        :type: list[str]
        """

        self._phone_numbers = phone_numbers

    @property
    def surname_father(self):
        """Gets the surname_father of this UserCompany.  # noqa: E501

        El apellido paterno del usuario  # noqa: E501

        :return: The surname_father of this UserCompany.  # noqa: E501
        :rtype: str
        """
        return self._surname_father

    @surname_father.setter
    def surname_father(self, surname_father):
        """Sets the surname_father of this UserCompany.

        El apellido paterno del usuario  # noqa: E501

        :param surname_father: The surname_father of this UserCompany.  # noqa: E501
        :type: str
        """

        self._surname_father = surname_father

    @property
    def surname_mother(self):
        """Gets the surname_mother of this UserCompany.  # noqa: E501

        El apellido materno del usuario  # noqa: E501

        :return: The surname_mother of this UserCompany.  # noqa: E501
        :rtype: str
        """
        return self._surname_mother

    @surname_mother.setter
    def surname_mother(self, surname_mother):
        """Sets the surname_mother of this UserCompany.

        El apellido materno del usuario  # noqa: E501

        :param surname_mother: The surname_mother of this UserCompany.  # noqa: E501
        :type: str
        """

        self._surname_mother = surname_mother

    @property
    def user_name(self):
        """Gets the user_name of this UserCompany.  # noqa: E501

        El nombre del usuario de acceso  # noqa: E501

        :return: The user_name of this UserCompany.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this UserCompany.

        El nombre del usuario de acceso  # noqa: E501

        :param user_name: The user_name of this UserCompany.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserCompany, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserCompany):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.cuentas_de_beneficiarios_spei_api import CuentasDeBeneficiariosSPEIApi  # noqa: E501
from wire4_client.rest import ApiException


class TestCuentasDeBeneficiariosSPEIApi(unittest.TestCase):
    """CuentasDeBeneficiariosSPEIApi unit test stubs"""

    def setUp(self):
        self.api = api.cuentas_de_beneficiarios_spei_api.CuentasDeBeneficiariosSPEIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_authorize_accounts_pending_put(self):
        """Test case for authorize_accounts_pending_put

        Solicitud para agrupar cuentas de beneficiarios SPEI/SPID en estado pendiente.  # noqa: E501
        """
        pass

    def test_delete_account_using_delete(self):
        """Test case for delete_account_using_delete

        Elimina la cuenta del beneficiario  # noqa: E501
        """
        pass

    def test_get_available_relationships_monex_using_get(self):
        """Test case for get_available_relationships_monex_using_get

        Consulta de relaciones  # noqa: E501
        """
        pass

    def test_get_beneficiaries_by_request_id(self):
        """Test case for get_beneficiaries_by_request_id

        Consulta los beneficiarios por el identificador de la petición de registro  # noqa: E501
        """
        pass

    def test_get_beneficiaries_for_account_using_get(self):
        """Test case for get_beneficiaries_for_account_using_get

        Consulta los beneficiarios registrados  # noqa: E501
        """
        pass

    def test_pre_register_accounts_using_post(self):
        """Test case for pre_register_accounts_using_post

        Pre-registro de cuentas de beneficiarios SPEI®.  # noqa: E501
        """
        pass

    def test_remove_beneficiaries_pending_using_delete(self):
        """Test case for remove_beneficiaries_pending_using_delete

        Eliminación de beneficiarios SPEI® sin confirmar  # noqa: E501
        """
        pass

    def test_update_amount_limit_account_using_put(self):
        """Test case for update_amount_limit_account_using_put

        Solicitud para actualizar el monto límite de una cuenta  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.message_cep import MessageCEP  # noqa: F401,E501
from wire4_client.models.message_institution import MessageInstitution  # noqa: F401,E501


class Deposit(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'beneficiary_account': 'str',
        'beneficiary_name': 'str',
        'beneficiary_rfc': 'str',
        'cep': 'MessageCEP',
        'clave_rastreo': 'str',
        'confirm_date': 'datetime',
        'currency_code': 'str',
        'deposit_date': 'datetime',
        'depositant': 'str',
        'depositant_alias': 'str',
        'depositant_clabe': 'str',
        'depositant_email': 'str',
        'depositant_rfc': 'str',
        'description': 'str',
        'monex_description': 'str',
        'monex_transaction_id': 'str',
        'reference': 'str',
        'sender_account': 'str',
        'sender_bank': 'MessageInstitution',
        'sender_name': 'str',
        'sender_rfc': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'beneficiary_account': 'beneficiary_account',
        'beneficiary_name': 'beneficiary_name',
        'beneficiary_rfc': 'beneficiary_rfc',
        'cep': 'cep',
        'clave_rastreo': 'clave_rastreo',
        'confirm_date': 'confirm_date',
        'currency_code': 'currency_code',
        'deposit_date': 'deposit_date',
        'depositant': 'depositant',
        'depositant_alias': 'depositant_alias',
        'depositant_clabe': 'depositant_clabe',
        'depositant_email': 'depositant_email',
        'depositant_rfc': 'depositant_rfc',
        'description': 'description',
        'monex_description': 'monex_description',
        'monex_transaction_id': 'monex_transaction_id',
        'reference': 'reference',
        'sender_account': 'sender_account',
        'sender_bank': 'sender_bank',
        'sender_name': 'sender_name',
        'sender_rfc': 'sender_rfc'
    }

    def __init__(self, amount=None, beneficiary_account=None, beneficiary_name=None, beneficiary_rfc=None, cep=None, clave_rastreo=None, confirm_date=None, currency_code=None, deposit_date=None, depositant=None, depositant_alias=None, depositant_clabe=None, depositant_email=None, depositant_rfc=None, description=None, monex_description=None, monex_transaction_id=None, reference=None, sender_account=None, sender_bank=None, sender_name=None, sender_rfc=None):  # noqa: E501
        """Deposit - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._beneficiary_account = None
        self._beneficiary_name = None
        self._beneficiary_rfc = None
        self._cep = None
        self._clave_rastreo = None
        self._confirm_date = None
        self._currency_code = None
        self._deposit_date = None
        self._depositant = None
        self._depositant_alias = None
        self._depositant_clabe = None
        self._depositant_email = None
        self._depositant_rfc = None
        self._description = None
        self._monex_description = None
        self._monex_transaction_id = None
        self._reference = None
        self._sender_account = None
        self._sender_bank = None
        self._sender_name = None
        self._sender_rfc = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if beneficiary_account is not None:
            self.beneficiary_account = beneficiary_account
        if beneficiary_name is not None:
            self.beneficiary_name = beneficiary_name
        if beneficiary_rfc is not None:
            self.beneficiary_rfc = beneficiary_rfc
        if cep is not None:
            self.cep = cep
        if clave_rastreo is not None:
            self.clave_rastreo = clave_rastreo
        if confirm_date is not None:
            self.confirm_date = confirm_date
        if currency_code is not None:
            self.currency_code = currency_code
        if deposit_date is not None:
            self.deposit_date = deposit_date
        if depositant is not None:
            self.depositant = depositant
        if depositant_alias is not None:
            self.depositant_alias = depositant_alias
        if depositant_clabe is not None:
            self.depositant_clabe = depositant_clabe
        if depositant_email is not None:
            self.depositant_email = depositant_email
        if depositant_rfc is not None:
            self.depositant_rfc = depositant_rfc
        if description is not None:
            self.description = description
        if monex_description is not None:
            self.monex_description = monex_description
        if monex_transaction_id is not None:
            self.monex_transaction_id = monex_transaction_id
        if reference is not None:
            self.reference = reference
        if sender_account is not None:
            self.sender_account = sender_account
        if sender_bank is not None:
            self.sender_bank = sender_bank
        if sender_name is not None:
            self.sender_name = sender_name
        if sender_rfc is not None:
            self.sender_rfc = sender_rfc

    @property
    def amount(self):
        """Gets the amount of this Deposit.  # noqa: E501

        Es el monto de la transferencia.  # noqa: E501

        :return: The amount of this Deposit.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Deposit.

        Es el monto de la transferencia.  # noqa: E501

        :param amount: The amount of this Deposit.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def beneficiary_account(self):
        """Gets the beneficiary_account of this Deposit.  # noqa: E501

        Es la cuenta del beneficiario.  # noqa: E501

        :return: The beneficiary_account of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_account

    @beneficiary_account.setter
    def beneficiary_account(self, beneficiary_account):
        """Sets the beneficiary_account of this Deposit.

        Es la cuenta del beneficiario.  # noqa: E501

        :param beneficiary_account: The beneficiary_account of this Deposit.  # noqa: E501
        :type: str
        """

        self._beneficiary_account = beneficiary_account

    @property
    def beneficiary_name(self):
        """Gets the beneficiary_name of this Deposit.  # noqa: E501

        Es el nombre del beneficiario.  # noqa: E501

        :return: The beneficiary_name of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_name

    @beneficiary_name.setter
    def beneficiary_name(self, beneficiary_name):
        """Sets the beneficiary_name of this Deposit.

        Es el nombre del beneficiario.  # noqa: E501

        :param beneficiary_name: The beneficiary_name of this Deposit.  # noqa: E501
        :type: str
        """

        self._beneficiary_name = beneficiary_name

    @property
    def beneficiary_rfc(self):
        """Gets the beneficiary_rfc of this Deposit.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) del beneficiario.  # noqa: E501

        :return: The beneficiary_rfc of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._beneficiary_rfc

    @beneficiary_rfc.setter
    def beneficiary_rfc(self, beneficiary_rfc):
        """Sets the beneficiary_rfc of this Deposit.

        Es el Registro Federal de Contribuyentes (RFC) del beneficiario.  # noqa: E501

        :param beneficiary_rfc: The beneficiary_rfc of this Deposit.  # noqa: E501
        :type: str
        """

        self._beneficiary_rfc = beneficiary_rfc

    @property
    def cep(self):
        """Gets the cep of this Deposit.  # noqa: E501


        :return: The cep of this Deposit.  # noqa: E501
        :rtype: MessageCEP
        """
        return self._cep

    @cep.setter
    def cep(self, cep):
        """Sets the cep of this Deposit.


        :param cep: The cep of this Deposit.  # noqa: E501
        :type: MessageCEP
        """

        self._cep = cep

    @property
    def clave_rastreo(self):
        """Gets the clave_rastreo of this Deposit.  # noqa: E501

        Es la clave de rastreo de la transferencia.  # noqa: E501

        :return: The clave_rastreo of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._clave_rastreo

    @clave_rastreo.setter
    def clave_rastreo(self, clave_rastreo):
        """Sets the clave_rastreo of this Deposit.

        Es la clave de rastreo de la transferencia.  # noqa: E501

        :param clave_rastreo: The clave_rastreo of this Deposit.  # noqa: E501
        :type: str
        """

        self._clave_rastreo = clave_rastreo

    @property
    def confirm_date(self):
        """Gets the confirm_date of this Deposit.  # noqa: E501

        Es la fecha de confirmación del deposito. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The confirm_date of this Deposit.  # noqa: E501
        :rtype: datetime
        """
        return self._confirm_date

    @confirm_date.setter
    def confirm_date(self, confirm_date):
        """Sets the confirm_date of this Deposit.

        Es la fecha de confirmación del deposito. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param confirm_date: The confirm_date of this Deposit.  # noqa: E501
        :type: datetime
        """

        self._confirm_date = confirm_date

    @property
    def currency_code(self):
        """Gets the currency_code of this Deposit.  # noqa: E501

        Es el código de divisa de la transferencia. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :return: The currency_code of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """Sets the currency_code of this Deposit.

        Es el código de divisa de la transferencia. Es en el formato estándar de 3 dígitos, por ejemplo para el peso mexicano: <b>MXP</b>, para el dólar estadounidense: <b>USD</b>.  # noqa: E501

        :param currency_code: The currency_code of this Deposit.  # noqa: E501
        :type: str
        """

        self._currency_code = currency_code

    @property
    def deposit_date(self):
        """Gets the deposit_date of this Deposit.  # noqa: E501

        Es la fecha del deposito.  Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The deposit_date of this Deposit.  # noqa: E501
        :rtype: datetime
        """
        return self._deposit_date

    @deposit_date.setter
    def deposit_date(self, deposit_date):
        """Sets the deposit_date of this Deposit.

        Es la fecha del deposito.  Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param deposit_date: The deposit_date of this Deposit.  # noqa: E501
        :type: datetime
        """

        self._deposit_date = deposit_date

    @property
    def depositant(self):
        """Gets the depositant of this Deposit.  # noqa: E501

        Es el depositante.  # noqa: E501

        :return: The depositant of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._depositant

    @depositant.setter
    def depositant(self, depositant):
        """Sets the depositant of this Deposit.

        Es el depositante.  # noqa: E501

        :param depositant: The depositant of this Deposit.  # noqa: E501
        :type: str
        """

        self._depositant = depositant

    @property
    def depositant_alias(self):
        """Gets the depositant_alias of this Deposit.  # noqa: E501

        Es el alias asignado a la cuenta CABLE del depositante.  # noqa: E501

        :return: The depositant_alias of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._depositant_alias

    @depositant_alias.setter
    def depositant_alias(self, depositant_alias):
        """Sets the depositant_alias of this Deposit.

        Es el alias asignado a la cuenta CABLE del depositante.  # noqa: E501

        :param depositant_alias: The depositant_alias of this Deposit.  # noqa: E501
        :type: str
        """

        self._depositant_alias = depositant_alias

    @property
    def depositant_clabe(self):
        """Gets the depositant_clabe of this Deposit.  # noqa: E501

        Es la Cuenta CLABE interbancaria (de 18 dígitos) del depositante.  # noqa: E501

        :return: The depositant_clabe of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._depositant_clabe

    @depositant_clabe.setter
    def depositant_clabe(self, depositant_clabe):
        """Sets the depositant_clabe of this Deposit.

        Es la Cuenta CLABE interbancaria (de 18 dígitos) del depositante.  # noqa: E501

        :param depositant_clabe: The depositant_clabe of this Deposit.  # noqa: E501
        :type: str
        """

        self._depositant_clabe = depositant_clabe

    @property
    def depositant_email(self):
        """Gets the depositant_email of this Deposit.  # noqa: E501

        Es el correo electrónico (email) del depositante.  # noqa: E501

        :return: The depositant_email of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._depositant_email

    @depositant_email.setter
    def depositant_email(self, depositant_email):
        """Sets the depositant_email of this Deposit.

        Es el correo electrónico (email) del depositante.  # noqa: E501

        :param depositant_email: The depositant_email of this Deposit.  # noqa: E501
        :type: str
        """

        self._depositant_email = depositant_email

    @property
    def depositant_rfc(self):
        """Gets the depositant_rfc of this Deposit.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) del depositante.  # noqa: E501

        :return: The depositant_rfc of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._depositant_rfc

    @depositant_rfc.setter
    def depositant_rfc(self, depositant_rfc):
        """Sets the depositant_rfc of this Deposit.

        Es el Registro Federal de Contribuyentes (RFC) del depositante.  # noqa: E501

        :param depositant_rfc: The depositant_rfc of this Deposit.  # noqa: E501
        :type: str
        """

        self._depositant_rfc = depositant_rfc

    @property
    def description(self):
        """Gets the description of this Deposit.  # noqa: E501

        Es la descripción del traspaso.  # noqa: E501

        :return: The description of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Deposit.

        Es la descripción del traspaso.  # noqa: E501

        :param description: The description of this Deposit.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def monex_description(self):
        """Gets the monex_description of this Deposit.  # noqa: E501

        Es la descripción directa de Monex.  # noqa: E501

        :return: The monex_description of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._monex_description

    @monex_description.setter
    def monex_description(self, monex_description):
        """Sets the monex_description of this Deposit.

        Es la descripción directa de Monex.  # noqa: E501

        :param monex_description: The monex_description of this Deposit.  # noqa: E501
        :type: str
        """

        self._monex_description = monex_description

    @property
    def monex_transaction_id(self):
        """Gets the monex_transaction_id of this Deposit.  # noqa: E501

        es el identificador de la transferencia en Monex.  # noqa: E501

        :return: The monex_transaction_id of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._monex_transaction_id

    @monex_transaction_id.setter
    def monex_transaction_id(self, monex_transaction_id):
        """Sets the monex_transaction_id of this Deposit.

        es el identificador de la transferencia en Monex.  # noqa: E501

        :param monex_transaction_id: The monex_transaction_id of this Deposit.  # noqa: E501
        :type: str
        """

        self._monex_transaction_id = monex_transaction_id

    @property
    def reference(self):
        """Gets the reference of this Deposit.  # noqa: E501

        Es la referencia del depósito.  # noqa: E501

        :return: The reference of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this Deposit.

        Es la referencia del depósito.  # noqa: E501

        :param reference: The reference of this Deposit.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def sender_account(self):
        """Gets the sender_account of this Deposit.  # noqa: E501

        Es la cuenta del ordenante.  # noqa: E501

        :return: The sender_account of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._sender_account

    @sender_account.setter
    def sender_account(self, sender_account):
        """Sets the sender_account of this Deposit.

        Es la cuenta del ordenante.  # noqa: E501

        :param sender_account: The sender_account of this Deposit.  # noqa: E501
        :type: str
        """

        self._sender_account = sender_account

    @property
    def sender_bank(self):
        """Gets the sender_bank of this Deposit.  # noqa: E501


        :return: The sender_bank of this Deposit.  # noqa: E501
        :rtype: MessageInstitution
        """
        return self._sender_bank

    @sender_bank.setter
    def sender_bank(self, sender_bank):
        """Sets the sender_bank of this Deposit.


        :param sender_bank: The sender_bank of this Deposit.  # noqa: E501
        :type: MessageInstitution
        """

        self._sender_bank = sender_bank

    @property
    def sender_name(self):
        """Gets the sender_name of this Deposit.  # noqa: E501

        Es el nombre del ordenante.  # noqa: E501

        :return: The sender_name of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._sender_name

    @sender_name.setter
    def sender_name(self, sender_name):
        """Sets the sender_name of this Deposit.

        Es el nombre del ordenante.  # noqa: E501

        :param sender_name: The sender_name of this Deposit.  # noqa: E501
        :type: str
        """

        self._sender_name = sender_name

    @property
    def sender_rfc(self):
        """Gets the sender_rfc of this Deposit.  # noqa: E501

        Es el Registro Federal de Contribuyentes (RFC) de la cuenta ordenante.  # noqa: E501

        :return: The sender_rfc of this Deposit.  # noqa: E501
        :rtype: str
        """
        return self._sender_rfc

    @sender_rfc.setter
    def sender_rfc(self, sender_rfc):
        """Sets the sender_rfc of this Deposit.

        Es el Registro Federal de Contribuyentes (RFC) de la cuenta ordenante.  # noqa: E501

        :param sender_rfc: The sender_rfc of this Deposit.  # noqa: E501
        :type: str
        """

        self._sender_rfc = sender_rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Deposit, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Deposit):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MessageWebHook(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'str',
        'created': 'datetime',
        'data': 'object',
        'id': 'str',
        'livemode': 'bool',
        'object': 'str',
        'pending_webhooks': 'int',
        'request': 'str',
        'type': 'str'
    }

    attribute_map = {
        'api_version': 'api_version',
        'created': 'created',
        'data': 'data',
        'id': 'id',
        'livemode': 'livemode',
        'object': 'object',
        'pending_webhooks': 'pending_webhooks',
        'request': 'request',
        'type': 'type'
    }

    def __init__(self, api_version=None, created=None, data=None, id=None, livemode=None, object=None, pending_webhooks=None, request=None, type=None):  # noqa: E501
        """MessageWebHook - a model defined in Swagger"""  # noqa: E501
        self._api_version = None
        self._created = None
        self._data = None
        self._id = None
        self._livemode = None
        self._object = None
        self._pending_webhooks = None
        self._request = None
        self._type = None
        self.discriminator = None
        if api_version is not None:
            self.api_version = api_version
        if created is not None:
            self.created = created
        if data is not None:
            self.data = data
        if id is not None:
            self.id = id
        if livemode is not None:
            self.livemode = livemode
        if object is not None:
            self.object = object
        if pending_webhooks is not None:
            self.pending_webhooks = pending_webhooks
        if request is not None:
            self.request = request
        if type is not None:
            self.type = type

    @property
    def api_version(self):
        """Gets the api_version of this MessageWebHook.  # noqa: E501

        Es la versión de esta API.  # noqa: E501

        :return: The api_version of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this MessageWebHook.

        Es la versión de esta API.  # noqa: E501

        :param api_version: The api_version of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._api_version = api_version

    @property
    def created(self):
        """Gets the created of this MessageWebHook.  # noqa: E501

        Fecha de creación del mensaje.  # noqa: E501

        :return: The created of this MessageWebHook.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this MessageWebHook.

        Fecha de creación del mensaje.  # noqa: E501

        :param created: The created of this MessageWebHook.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def data(self):
        """Gets the data of this MessageWebHook.  # noqa: E501

        Es el objeto que contiene la información del evento.  # noqa: E501

        :return: The data of this MessageWebHook.  # noqa: E501
        :rtype: object
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this MessageWebHook.

        Es el objeto que contiene la información del evento.  # noqa: E501

        :param data: The data of this MessageWebHook.  # noqa: E501
        :type: object
        """

        self._data = data

    @property
    def id(self):
        """Gets the id of this MessageWebHook.  # noqa: E501

        Es el identificador del mensaje.  # noqa: E501

        :return: The id of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MessageWebHook.

        Es el identificador del mensaje.  # noqa: E501

        :param id: The id of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def livemode(self):
        """Gets the livemode of this MessageWebHook.  # noqa: E501

        Indica si proviene de un entorno productivo.  # noqa: E501

        :return: The livemode of this MessageWebHook.  # noqa: E501
        :rtype: bool
        """
        return self._livemode

    @livemode.setter
    def livemode(self, livemode):
        """Sets the livemode of this MessageWebHook.

        Indica si proviene de un entorno productivo.  # noqa: E501

        :param livemode: The livemode of this MessageWebHook.  # noqa: E501
        :type: bool
        """

        self._livemode = livemode

    @property
    def object(self):
        """Gets the object of this MessageWebHook.  # noqa: E501

        Tipo de objeto  que contiene el mensaje en el atributo 'data'. Los posibles valores son:  <ul><li>subscription</li>, <li>beneficiary</li>, <li>spei_outgoing</li>, <li>spei_incoming</li>, <li>spid_outgoing</li>, <li>request_outgoing</li><ul>   # noqa: E501

        :return: The object of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._object

    @object.setter
    def object(self, object):
        """Sets the object of this MessageWebHook.

        Tipo de objeto  que contiene el mensaje en el atributo 'data'. Los posibles valores son:  <ul><li>subscription</li>, <li>beneficiary</li>, <li>spei_outgoing</li>, <li>spei_incoming</li>, <li>spid_outgoing</li>, <li>request_outgoing</li><ul>   # noqa: E501

        :param object: The object of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._object = object

    @property
    def pending_webhooks(self):
        """Gets the pending_webhooks of this MessageWebHook.  # noqa: E501

        Es el número de mensajes pendientes de enviar.  # noqa: E501

        :return: The pending_webhooks of this MessageWebHook.  # noqa: E501
        :rtype: int
        """
        return self._pending_webhooks

    @pending_webhooks.setter
    def pending_webhooks(self, pending_webhooks):
        """Sets the pending_webhooks of this MessageWebHook.

        Es el número de mensajes pendientes de enviar.  # noqa: E501

        :param pending_webhooks: The pending_webhooks of this MessageWebHook.  # noqa: E501
        :type: int
        """

        self._pending_webhooks = pending_webhooks

    @property
    def request(self):
        """Gets the request of this MessageWebHook.  # noqa: E501

        Es el identificador del recurso relacionado.  # noqa: E501

        :return: The request of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._request

    @request.setter
    def request(self, request):
        """Sets the request of this MessageWebHook.

        Es el identificador del recurso relacionado.  # noqa: E501

        :param request: The request of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._request = request

    @property
    def type(self):
        """Gets the type of this MessageWebHook.  # noqa: E501

        El tipo evento que se está enviando en la notificación.  # noqa: E501

        :return: The type of this MessageWebHook.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this MessageWebHook.

        El tipo evento que se está enviando en la notificación.  # noqa: E501

        :param type: The type of this MessageWebHook.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageWebHook, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageWebHook):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MessageSubscription(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'contract': 'str',
        'masked_contract': 'str',
        'subscription': 'str',
        'user': 'str',
        'user_key': 'str',
        'user_secret': 'str'
    }

    attribute_map = {
        'contract': 'contract',
        'masked_contract': 'masked_contract',
        'subscription': 'subscription',
        'user': 'user',
        'user_key': 'user_key',
        'user_secret': 'user_secret'
    }

    def __init__(self, contract=None, masked_contract=None, subscription=None, user=None, user_key=None, user_secret=None):  # noqa: E501
        """MessageSubscription - a model defined in Swagger"""  # noqa: E501
        self._contract = None
        self._masked_contract = None
        self._subscription = None
        self._user = None
        self._user_key = None
        self._user_secret = None
        self.discriminator = None
        if contract is not None:
            self.contract = contract
        if masked_contract is not None:
            self.masked_contract = masked_contract
        if subscription is not None:
            self.subscription = subscription
        if user is not None:
            self.user = user
        if user_key is not None:
            self.user_key = user_key
        if user_secret is not None:
            self.user_secret = user_secret

    @property
    def contract(self):
        """Gets the contract of this MessageSubscription.  # noqa: E501

        Es el contrato Monex, con el que se suscribió el cliente Monex en Wire4.  # noqa: E501

        :return: The contract of this MessageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this MessageSubscription.

        Es el contrato Monex, con el que se suscribió el cliente Monex en Wire4.  # noqa: E501

        :param contract: The contract of this MessageSubscription.  # noqa: E501
        :type: str
        """

        self._contract = contract

    @property
    def masked_contract(self):
        """Gets the masked_contract of this MessageSubscription.  # noqa: E501

        Es el contrato enmascarado de Monex, con el que se suscribió el cliente Monex en Wire4.  # noqa: E501

        :return: The masked_contract of this MessageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._masked_contract

    @masked_contract.setter
    def masked_contract(self, masked_contract):
        """Sets the masked_contract of this MessageSubscription.

        Es el contrato enmascarado de Monex, con el que se suscribió el cliente Monex en Wire4.  # noqa: E501

        :param masked_contract: The masked_contract of this MessageSubscription.  # noqa: E501
        :type: str
        """

        self._masked_contract = masked_contract

    @property
    def subscription(self):
        """Gets the subscription of this MessageSubscription.  # noqa: E501

        Es el identificador de la suscripción, el que se utilizará en las operaciones que solicitan una suscripción.  # noqa: E501

        :return: The subscription of this MessageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this MessageSubscription.

        Es el identificador de la suscripción, el que se utilizará en las operaciones que solicitan una suscripción.  # noqa: E501

        :param subscription: The subscription of this MessageSubscription.  # noqa: E501
        :type: str
        """

        self._subscription = subscription

    @property
    def user(self):
        """Gets the user of this MessageSubscription.  # noqa: E501

        Es el usuario enmascardo, con el que se suscribió el cliente Monex en Wire4.  # noqa: E501

        :return: The user of this MessageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this MessageSubscription.

        Es el usuario enmascardo, con el que se suscribió el cliente Monex en Wire4.  # noqa: E501

        :param user: The user of this MessageSubscription.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def user_key(self):
        """Gets the user_key of this MessageSubscription.  # noqa: E501

        Es el usuario proporcionado por Wire4, el cuál se debe utilizar para autenticar a esta suscripción.  # noqa: E501

        :return: The user_key of this MessageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._user_key

    @user_key.setter
    def user_key(self, user_key):
        """Sets the user_key of this MessageSubscription.

        Es el usuario proporcionado por Wire4, el cuál se debe utilizar para autenticar a esta suscripción.  # noqa: E501

        :param user_key: The user_key of this MessageSubscription.  # noqa: E501
        :type: str
        """

        self._user_key = user_key

    @property
    def user_secret(self):
        """Gets the user_secret of this MessageSubscription.  # noqa: E501

        Es la contraseña proporcionada por Wire4, la que se debe utilizar para autenticar a esta suscripción.  # noqa: E501

        :return: The user_secret of this MessageSubscription.  # noqa: E501
        :rtype: str
        """
        return self._user_secret

    @user_secret.setter
    def user_secret(self, user_secret):
        """Sets the user_secret of this MessageSubscription.

        Es la contraseña proporcionada por Wire4, la que se debe utilizar para autenticar a esta suscripción.  # noqa: E501

        :param user_secret: The user_secret of this MessageSubscription.  # noqa: E501
        :type: str
        """

        self._user_secret = user_secret

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MessageSubscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MessageSubscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PreMonexAuthorization(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'business_name': 'str',
        'cancel_return_url': 'str',
        'return_url': 'str',
        'rfc': 'str'
    }

    attribute_map = {
        'business_name': 'business_name',
        'cancel_return_url': 'cancel_return_url',
        'return_url': 'return_url',
        'rfc': 'rfc'
    }

    def __init__(self, business_name=None, cancel_return_url=None, return_url=None, rfc=None):  # noqa: E501
        """PreMonexAuthorization - a model defined in Swagger"""  # noqa: E501
        self._business_name = None
        self._cancel_return_url = None
        self._return_url = None
        self._rfc = None
        self.discriminator = None
        self.business_name = business_name
        self.cancel_return_url = cancel_return_url
        self.return_url = return_url
        self.rfc = rfc

    @property
    def business_name(self):
        """Gets the business_name of this PreMonexAuthorization.  # noqa: E501

        Razón social de asociada al RFC a la que debe pertenecer el contrato que se solicita  # noqa: E501

        :return: The business_name of this PreMonexAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._business_name

    @business_name.setter
    def business_name(self, business_name):
        """Sets the business_name of this PreMonexAuthorization.

        Razón social de asociada al RFC a la que debe pertenecer el contrato que se solicita  # noqa: E501

        :param business_name: The business_name of this PreMonexAuthorization.  # noqa: E501
        :type: str
        """
        if business_name is None:
            raise ValueError("Invalid value for `business_name`, must not be `None`")  # noqa: E501

        self._business_name = business_name

    @property
    def cancel_return_url(self):
        """Gets the cancel_return_url of this PreMonexAuthorization.  # noqa: E501

        Url a la que se redirigira en caso de que el cliente cancele el registro  # noqa: E501

        :return: The cancel_return_url of this PreMonexAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._cancel_return_url

    @cancel_return_url.setter
    def cancel_return_url(self, cancel_return_url):
        """Sets the cancel_return_url of this PreMonexAuthorization.

        Url a la que se redirigira en caso de que el cliente cancele el registro  # noqa: E501

        :param cancel_return_url: The cancel_return_url of this PreMonexAuthorization.  # noqa: E501
        :type: str
        """
        if cancel_return_url is None:
            raise ValueError("Invalid value for `cancel_return_url`, must not be `None`")  # noqa: E501

        self._cancel_return_url = cancel_return_url

    @property
    def return_url(self):
        """Gets the return_url of this PreMonexAuthorization.  # noqa: E501

        Url a la que se redirigirá en caso de exito  # noqa: E501

        :return: The return_url of this PreMonexAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._return_url

    @return_url.setter
    def return_url(self, return_url):
        """Sets the return_url of this PreMonexAuthorization.

        Url a la que se redirigirá en caso de exito  # noqa: E501

        :param return_url: The return_url of this PreMonexAuthorization.  # noqa: E501
        :type: str
        """
        if return_url is None:
            raise ValueError("Invalid value for `return_url`, must not be `None`")  # noqa: E501

        self._return_url = return_url

    @property
    def rfc(self):
        """Gets the rfc of this PreMonexAuthorization.  # noqa: E501

        RFC de la empresa a la que debe pertenecer el contrato solicitado, si no se especifica este valor no se realiza validación  # noqa: E501

        :return: The rfc of this PreMonexAuthorization.  # noqa: E501
        :rtype: str
        """
        return self._rfc

    @rfc.setter
    def rfc(self, rfc):
        """Sets the rfc of this PreMonexAuthorization.

        RFC de la empresa a la que debe pertenecer el contrato solicitado, si no se especifica este valor no se realiza validación  # noqa: E501

        :param rfc: The rfc of this PreMonexAuthorization.  # noqa: E501
        :type: str
        """
        if rfc is None:
            raise ValueError("Invalid value for `rfc`, must not be `None`")  # noqa: E501

        self._rfc = rfc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PreMonexAuthorization, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PreMonexAuthorization):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CodiCodeRequestDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'concept': 'str',
        'due_date': 'datetime',
        'metadata': 'str',
        'order_id': 'str',
        'phone_number': 'str',
        'type': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'concept': 'concept',
        'due_date': 'due_date',
        'metadata': 'metadata',
        'order_id': 'order_id',
        'phone_number': 'phone_number',
        'type': 'type'
    }

    def __init__(self, amount=None, concept=None, due_date=None, metadata=None, order_id=None, phone_number=None, type=None):  # noqa: E501
        """CodiCodeRequestDTO - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._concept = None
        self._due_date = None
        self._metadata = None
        self._order_id = None
        self._phone_number = None
        self._type = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        self.concept = concept
        self.due_date = due_date
        if metadata is not None:
            self.metadata = metadata
        self.order_id = order_id
        if phone_number is not None:
            self.phone_number = phone_number
        self.type = type

    @property
    def amount(self):
        """Gets the amount of this CodiCodeRequestDTO.  # noqa: E501

        Monto del pago CODI®  # noqa: E501

        :return: The amount of this CodiCodeRequestDTO.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CodiCodeRequestDTO.

        Monto del pago CODI®  # noqa: E501

        :param amount: The amount of this CodiCodeRequestDTO.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def concept(self):
        """Gets the concept of this CodiCodeRequestDTO.  # noqa: E501

        Descripción del pago CODI®  # noqa: E501

        :return: The concept of this CodiCodeRequestDTO.  # noqa: E501
        :rtype: str
        """
        return self._concept

    @concept.setter
    def concept(self, concept):
        """Sets the concept of this CodiCodeRequestDTO.

        Descripción del pago CODI®  # noqa: E501

        :param concept: The concept of this CodiCodeRequestDTO.  # noqa: E501
        :type: str
        """
        if concept is None:
            raise ValueError("Invalid value for `concept`, must not be `None`")  # noqa: E501

        self._concept = concept

    @property
    def due_date(self):
        """Gets the due_date of this CodiCodeRequestDTO.  # noqa: E501

        Fecha de operación pago CODI®, formato: yyyy-MM-dd'T'HH:mm:ss  # noqa: E501

        :return: The due_date of this CodiCodeRequestDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this CodiCodeRequestDTO.

        Fecha de operación pago CODI®, formato: yyyy-MM-dd'T'HH:mm:ss  # noqa: E501

        :param due_date: The due_date of this CodiCodeRequestDTO.  # noqa: E501
        :type: datetime
        """
        if due_date is None:
            raise ValueError("Invalid value for `due_date`, must not be `None`")  # noqa: E501

        self._due_date = due_date

    @property
    def metadata(self):
        """Gets the metadata of this CodiCodeRequestDTO.  # noqa: E501

        Campo de metada CODI®, longitud máxima determinada por configuracion de la empresa, por defecto 100 caracteres  # noqa: E501

        :return: The metadata of this CodiCodeRequestDTO.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this CodiCodeRequestDTO.

        Campo de metada CODI®, longitud máxima determinada por configuracion de la empresa, por defecto 100 caracteres  # noqa: E501

        :param metadata: The metadata of this CodiCodeRequestDTO.  # noqa: E501
        :type: str
        """

        self._metadata = metadata

    @property
    def order_id(self):
        """Gets the order_id of this CodiCodeRequestDTO.  # noqa: E501

        Referencia de la transferencia asignada por el cliente  # noqa: E501

        :return: The order_id of this CodiCodeRequestDTO.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this CodiCodeRequestDTO.

        Referencia de la transferencia asignada por el cliente  # noqa: E501

        :param order_id: The order_id of this CodiCodeRequestDTO.  # noqa: E501
        :type: str
        """
        if order_id is None:
            raise ValueError("Invalid value for `order_id`, must not be `None`")  # noqa: E501

        self._order_id = order_id

    @property
    def phone_number(self):
        """Gets the phone_number of this CodiCodeRequestDTO.  # noqa: E501

        Número de teléfono móvil en caso de ser un pago CODI® usando 'PUSH_NOTIFICATION' estecampo sería obligatorio  # noqa: E501

        :return: The phone_number of this CodiCodeRequestDTO.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this CodiCodeRequestDTO.

        Número de teléfono móvil en caso de ser un pago CODI® usando 'PUSH_NOTIFICATION' estecampo sería obligatorio  # noqa: E501

        :param phone_number: The phone_number of this CodiCodeRequestDTO.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def type(self):
        """Gets the type of this CodiCodeRequestDTO.  # noqa: E501

        El tipo de código QR para pago con CODI®  # noqa: E501

        :return: The type of this CodiCodeRequestDTO.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CodiCodeRequestDTO.

        El tipo de código QR para pago con CODI®  # noqa: E501

        :param type: The type of this CodiCodeRequestDTO.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["PUSH_NOTIFICATION", "QR_CODE"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CodiCodeRequestDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodiCodeRequestDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SalesPointFound(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'access_ip': 'str',
        'account': 'str',
        'created_at': 'datetime',
        'name': 'str',
        'public_id': 'str',
        'status': 'str',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'access_ip': 'access_ip',
        'account': 'account',
        'created_at': 'created_at',
        'name': 'name',
        'public_id': 'public_id',
        'status': 'status',
        'updated_at': 'updated_at'
    }

    def __init__(self, access_ip=None, account=None, created_at=None, name=None, public_id=None, status=None, updated_at=None):  # noqa: E501
        """SalesPointFound - a model defined in Swagger"""  # noqa: E501
        self._access_ip = None
        self._account = None
        self._created_at = None
        self._name = None
        self._public_id = None
        self._status = None
        self._updated_at = None
        self.discriminator = None
        if access_ip is not None:
            self.access_ip = access_ip
        if account is not None:
            self.account = account
        if created_at is not None:
            self.created_at = created_at
        if name is not None:
            self.name = name
        if public_id is not None:
            self.public_id = public_id
        if status is not None:
            self.status = status
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def access_ip(self):
        """Gets the access_ip of this SalesPointFound.  # noqa: E501

        Es la dirección IP desde la que accede el punto de venta a wire4 y a la que se devuelven las notificaciones.  # noqa: E501

        :return: The access_ip of this SalesPointFound.  # noqa: E501
        :rtype: str
        """
        return self._access_ip

    @access_ip.setter
    def access_ip(self, access_ip):
        """Sets the access_ip of this SalesPointFound.

        Es la dirección IP desde la que accede el punto de venta a wire4 y a la que se devuelven las notificaciones.  # noqa: E501

        :param access_ip: The access_ip of this SalesPointFound.  # noqa: E501
        :type: str
        """

        self._access_ip = access_ip

    @property
    def account(self):
        """Gets the account of this SalesPointFound.  # noqa: E501

        Es la cuenta registra para el punto de venta.  # noqa: E501

        :return: The account of this SalesPointFound.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this SalesPointFound.

        Es la cuenta registra para el punto de venta.  # noqa: E501

        :param account: The account of this SalesPointFound.  # noqa: E501
        :type: str
        """

        self._account = account

    @property
    def created_at(self):
        """Gets the created_at of this SalesPointFound.  # noqa: E501

        Es la fecha en la que se creó el punto de venta. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The created_at of this SalesPointFound.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SalesPointFound.

        Es la fecha en la que se creó el punto de venta. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param created_at: The created_at of this SalesPointFound.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def name(self):
        """Gets the name of this SalesPointFound.  # noqa: E501

        Es el nombre del punto de venta.  # noqa: E501

        :return: The name of this SalesPointFound.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SalesPointFound.

        Es el nombre del punto de venta.  # noqa: E501

        :param name: The name of this SalesPointFound.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def public_id(self):
        """Gets the public_id of this SalesPointFound.  # noqa: E501

        Es el identificador del punto de venta.  # noqa: E501

        :return: The public_id of this SalesPointFound.  # noqa: E501
        :rtype: str
        """
        return self._public_id

    @public_id.setter
    def public_id(self, public_id):
        """Sets the public_id of this SalesPointFound.

        Es el identificador del punto de venta.  # noqa: E501

        :param public_id: The public_id of this SalesPointFound.  # noqa: E501
        :type: str
        """

        self._public_id = public_id

    @property
    def status(self):
        """Gets the status of this SalesPointFound.  # noqa: E501

        Es el estado (estatus) del punto de venta. Puede ser \"ACTIVE\" o \"INACTIVO\".  # noqa: E501

        :return: The status of this SalesPointFound.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SalesPointFound.

        Es el estado (estatus) del punto de venta. Puede ser \"ACTIVE\" o \"INACTIVO\".  # noqa: E501

        :param status: The status of this SalesPointFound.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def updated_at(self):
        """Gets the updated_at of this SalesPointFound.  # noqa: E501

        Es la fecha en la que se actualizó el punto de venta. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The updated_at of this SalesPointFound.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SalesPointFound.

        Es la fecha en la que se actualizó el punto de venta. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param updated_at: The updated_at of this SalesPointFound.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SalesPointFound, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SalesPointFound):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from wire4_client.api_client import ApiClient


class TransferenciasSPEIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_authorization_transactions_group(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Agrupa transacciones bajo un request_id   # noqa: E501

        Agrupa transacciones SPEI/SPID en un mismo transaction_id, posteriormente genera la dirección URL del centro de autorización para la confirmación de las transacciones. <br><br>Las transacciones deben estar en estatus PENDING y pertenecer a un mismo contrato.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_authorization_transactions_group(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AuthorizationTransactionGroup body: Objeto con la información para agrupar transacciones existentes y autorizarlas de forma conjunta. (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el Identificador de la suscripción. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_authorization_transactions_group_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.create_authorization_transactions_group_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
            return data

    def create_authorization_transactions_group_with_http_info(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Agrupa transacciones bajo un request_id   # noqa: E501

        Agrupa transacciones SPEI/SPID en un mismo transaction_id, posteriormente genera la dirección URL del centro de autorización para la confirmación de las transacciones. <br><br>Las transacciones deben estar en estatus PENDING y pertenecer a un mismo contrato.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_authorization_transactions_group_with_http_info(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AuthorizationTransactionGroup body: Objeto con la información para agrupar transacciones existentes y autorizarlas de forma conjunta. (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el Identificador de la suscripción. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_authorization_transactions_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_authorization_transactions_group`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `create_authorization_transactions_group`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `create_authorization_transactions_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/transactions/group', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenRequiredResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def drop_transactions_pending_using_delete(self, authorization, request_id, subscription, **kwargs):  # noqa: E501
        """Eliminación de transferencias SPEI® pendientes  # noqa: E501

        Elimina un conjunto de transferencias en estado pendiente de confirmar o autorizar, en la cuenta del cliente Monex relacionada a la suscripción.<br><br><b>Nota:</b> Las transferencias no deben haber sido confirmadas o autorizadas por el cliente.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.drop_transactions_pending_using_delete(authorization, request_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str request_id: Identificador de las transferencias a eliminar. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :param str order_id: Listado de identificadores dentro del request_id para eliminar.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.drop_transactions_pending_using_delete_with_http_info(authorization, request_id, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.drop_transactions_pending_using_delete_with_http_info(authorization, request_id, subscription, **kwargs)  # noqa: E501
            return data

    def drop_transactions_pending_using_delete_with_http_info(self, authorization, request_id, subscription, **kwargs):  # noqa: E501
        """Eliminación de transferencias SPEI® pendientes  # noqa: E501

        Elimina un conjunto de transferencias en estado pendiente de confirmar o autorizar, en la cuenta del cliente Monex relacionada a la suscripción.<br><br><b>Nota:</b> Las transferencias no deben haber sido confirmadas o autorizadas por el cliente.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.drop_transactions_pending_using_delete_with_http_info(authorization, request_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str request_id: Identificador de las transferencias a eliminar. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :param str order_id: Listado de identificadores dentro del request_id para eliminar.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'request_id', 'subscription', 'order_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method drop_transactions_pending_using_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `drop_transactions_pending_using_delete`")  # noqa: E501
        # verify the required parameter 'request_id' is set
        if ('request_id' not in params or
                params['request_id'] is None):
            raise ValueError("Missing the required parameter `request_id` when calling `drop_transactions_pending_using_delete`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `drop_transactions_pending_using_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'request_id' in params:
            path_params['requestId'] = params['request_id']  # noqa: E501
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []
        if 'order_id' in params:
            query_params.append(('order_id', params['order_id']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/transactions/outcoming/spei/request/{requestId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def incoming_spei_transactions_report_using_get(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta de transferencias recibidas  # noqa: E501

        Realiza una consulta de las transferencias recibidas (depósitos) en la cuenta del cliente Monex relacionada a la suscripción, las transferencias que regresa este recuso son únicamente las transferencias  recibidas durante el día en el que se realiza la consulta. Para consultar transacciones que se encuentran en otras fechas se debe utilizar los parámetros de fecha inicial (beginDate) y fecha final (endDate), siempre deben de ir las dos ya que en caso de que falte una marcará error la consulta, si faltan las dos la consulta lanzará solo las del día, como se describe al inicio. El formato para las fechas es \"yyyy-MM-dd\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.incoming_spei_transactions_report_using_get(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :param str begin_date: Fecha inicial para filtrar los depósitos, se espera en formato 'yyyy-MM-dd'
        :param str end_date: Fecha final para filtrar los depósitos, se espera en formato 'yyyy-MM-dd'
        :return: list[Deposit]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.incoming_spei_transactions_report_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.incoming_spei_transactions_report_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
            return data

    def incoming_spei_transactions_report_using_get_with_http_info(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta de transferencias recibidas  # noqa: E501

        Realiza una consulta de las transferencias recibidas (depósitos) en la cuenta del cliente Monex relacionada a la suscripción, las transferencias que regresa este recuso son únicamente las transferencias  recibidas durante el día en el que se realiza la consulta. Para consultar transacciones que se encuentran en otras fechas se debe utilizar los parámetros de fecha inicial (beginDate) y fecha final (endDate), siempre deben de ir las dos ya que en caso de que falte una marcará error la consulta, si faltan las dos la consulta lanzará solo las del día, como se describe al inicio. El formato para las fechas es \"yyyy-MM-dd\"  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.incoming_spei_transactions_report_using_get_with_http_info(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :param str begin_date: Fecha inicial para filtrar los depósitos, se espera en formato 'yyyy-MM-dd'
        :param str end_date: Fecha final para filtrar los depósitos, se espera en formato 'yyyy-MM-dd'
        :return: list[Deposit]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'subscription', 'begin_date', 'end_date']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method incoming_spei_transactions_report_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `incoming_spei_transactions_report_using_get`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `incoming_spei_transactions_report_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []
        if 'begin_date' in params:
            query_params.append(('beginDate', params['begin_date']))  # noqa: E501
        if 'end_date' in params:
            query_params.append(('endDate', params['end_date']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/transactions/incoming/spei', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Deposit]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def out_comming_spei_request_id_transactions_report_using_get(self, authorization, request_id, subscription, **kwargs):  # noqa: E501
        """Consulta de transferencias de salida por identificador de petición  # noqa: E501

        Consulta las transferencias de salida registradas en una petición, las transferencias que regresa este recuso son únicamente las transferencias de salida agrupadas al identificador de la petición que se generó al hacer el registro de las transacciones el cuál se debe especificar como parte del path de este endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.out_comming_spei_request_id_transactions_report_using_get(authorization, request_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str request_id: Identificador de la petición a buscar. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: PaymentsRequestId
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.out_comming_spei_request_id_transactions_report_using_get_with_http_info(authorization, request_id, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.out_comming_spei_request_id_transactions_report_using_get_with_http_info(authorization, request_id, subscription, **kwargs)  # noqa: E501
            return data

    def out_comming_spei_request_id_transactions_report_using_get_with_http_info(self, authorization, request_id, subscription, **kwargs):  # noqa: E501
        """Consulta de transferencias de salida por identificador de petición  # noqa: E501

        Consulta las transferencias de salida registradas en una petición, las transferencias que regresa este recuso son únicamente las transferencias de salida agrupadas al identificador de la petición que se generó al hacer el registro de las transacciones el cuál se debe especificar como parte del path de este endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.out_comming_spei_request_id_transactions_report_using_get_with_http_info(authorization, request_id, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str request_id: Identificador de la petición a buscar. (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: PaymentsRequestId
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'request_id', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method out_comming_spei_request_id_transactions_report_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `out_comming_spei_request_id_transactions_report_using_get`")  # noqa: E501
        # verify the required parameter 'request_id' is set
        if ('request_id' not in params or
                params['request_id'] is None):
            raise ValueError("Missing the required parameter `request_id` when calling `out_comming_spei_request_id_transactions_report_using_get`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `out_comming_spei_request_id_transactions_report_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'request_id' in params:
            path_params['requestId'] = params['request_id']  # noqa: E501
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/transactions/outcoming/spei/{requestId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PaymentsRequestId',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def outgoing_spei_transactions_report_using_get(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta de transferencias realizadas  # noqa: E501

        Consulta las transferencias realizadas en la cuenta del cliente Monex relacionada a la suscripción, las transferencias que regresa este recuso son únicamente las transferencias recibidas en el día en el que se realiza la consulta.<br>Se pueden realizar consultas por <strong>order_id</strong> al realizar este tipo de consultas no importa el día en el que se realizó la transferencia  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.outgoing_spei_transactions_report_using_get(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :param str order_id: Es el identificador de la orden a buscar.
        :return: list[Payment]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.outgoing_spei_transactions_report_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.outgoing_spei_transactions_report_using_get_with_http_info(authorization, subscription, **kwargs)  # noqa: E501
            return data

    def outgoing_spei_transactions_report_using_get_with_http_info(self, authorization, subscription, **kwargs):  # noqa: E501
        """Consulta de transferencias realizadas  # noqa: E501

        Consulta las transferencias realizadas en la cuenta del cliente Monex relacionada a la suscripción, las transferencias que regresa este recuso son únicamente las transferencias recibidas en el día en el que se realiza la consulta.<br>Se pueden realizar consultas por <strong>order_id</strong> al realizar este tipo de consultas no importa el día en el que se realizó la transferencia  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.outgoing_spei_transactions_report_using_get_with_http_info(authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :param str order_id: Es el identificador de la orden a buscar.
        :return: list[Payment]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'subscription', 'order_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method outgoing_spei_transactions_report_using_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `outgoing_spei_transactions_report_using_get`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `outgoing_spei_transactions_report_using_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []
        if 'order_id' in params:
            query_params.append(('order_id', params['order_id']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/transactions/outcoming/spei', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Payment]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def register_outgoing_spei_transaction_using_post(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Registro de transferencias  # noqa: E501

        Se registra un conjunto de transferencias (una o más) a realizar en la cuenta del cliente Monex relacionada a la suscripción. En la respuesta se proporcionará una dirección URL que lo llevará al centro de autorización para que las transferencias sean confirmadas (autorizadas) por el cliente para que se efectúen, para ello debe ingresar la llave electrónica (Token).<br>  Nota: Debe considerar que el concepto de cada una de las transacciones solo debe contener caracteres alfanuméricos por lo que en caso de que se reciban caracteres como ñ o acentos serán sustituidos por n o en su caso por la letra sin acento. Los caracteres no alfanuméricos como pueden ser caracteres especiales serán eliminados.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_outgoing_spei_transaction_using_post(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TransactionsOutgoingRegister body: Información de las transferencias SPEI de salida (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.register_outgoing_spei_transaction_using_post_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
        else:
            (data) = self.register_outgoing_spei_transaction_using_post_with_http_info(body, authorization, subscription, **kwargs)  # noqa: E501
            return data

    def register_outgoing_spei_transaction_using_post_with_http_info(self, body, authorization, subscription, **kwargs):  # noqa: E501
        """Registro de transferencias  # noqa: E501

        Se registra un conjunto de transferencias (una o más) a realizar en la cuenta del cliente Monex relacionada a la suscripción. En la respuesta se proporcionará una dirección URL que lo llevará al centro de autorización para que las transferencias sean confirmadas (autorizadas) por el cliente para que se efectúen, para ello debe ingresar la llave electrónica (Token).<br>  Nota: Debe considerar que el concepto de cada una de las transacciones solo debe contener caracteres alfanuméricos por lo que en caso de que se reciban caracteres como ñ o acentos serán sustituidos por n o en su caso por la letra sin acento. Los caracteres no alfanuméricos como pueden ser caracteres especiales serán eliminados.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.register_outgoing_spei_transaction_using_post_with_http_info(body, authorization, subscription, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TransactionsOutgoingRegister body: Información de las transferencias SPEI de salida (required)
        :param str authorization: Header para token (required)
        :param str subscription: Es el identificador de la suscripción a esta API. (required)
        :return: TokenRequiredResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization', 'subscription']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method register_outgoing_spei_transaction_using_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `register_outgoing_spei_transaction_using_post`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `register_outgoing_spei_transaction_using_post`")  # noqa: E501
        # verify the required parameter 'subscription' is set
        if ('subscription' not in params or
                params['subscription'] is None):
            raise ValueError("Missing the required parameter `subscription` when calling `register_outgoing_spei_transaction_using_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'subscription' in params:
            path_params['subscription'] = params['subscription']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/subscriptions/{subscription}/transactions/outcoming/spei', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenRequiredResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.suscripciones_api import SuscripcionesApi  # noqa: E501
from wire4_client.rest import ApiException


class TestSuscripcionesApi(unittest.TestCase):
    """SuscripcionesApi unit test stubs"""

    def setUp(self):
        self.api = api.suscripciones_api.SuscripcionesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_subscription_status_using_put(self):
        """Test case for change_subscription_status_using_put

        Cambia el estatus de la suscripción  # noqa: E501
        """
        pass

    def test_change_subscription_use_using_patch(self):
        """Test case for change_subscription_use_using_patch

        Cambia el uso de la suscripción  # noqa: E501
        """
        pass

    def test_pre_enrollment_monex_user_using_post(self):
        """Test case for pre_enrollment_monex_user_using_post

        Pre-registro de una suscripción  # noqa: E501
        """
        pass

    def test_remove_enrollment_user_using_delete(self):
        """Test case for remove_enrollment_user_using_delete

        Elimina suscripción por su identificador.  # noqa: E501
        """
        pass

    def test_remove_subscription_pending_status_using_delete(self):
        """Test case for remove_subscription_pending_status_using_delete

        Elimina pre-registro de suscripción  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PaymentCODI(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'description': 'str',
        'error_message': 'str',
        'id': 'str',
        'operation_date': 'datetime',
        'status': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'description': 'description',
        'error_message': 'error_message',
        'id': 'id',
        'operation_date': 'operation_date',
        'status': 'status'
    }

    def __init__(self, amount=None, description=None, error_message=None, id=None, operation_date=None, status=None):  # noqa: E501
        """PaymentCODI - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._description = None
        self._error_message = None
        self._id = None
        self._operation_date = None
        self._status = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if description is not None:
            self.description = description
        if error_message is not None:
            self.error_message = error_message
        if id is not None:
            self.id = id
        if operation_date is not None:
            self.operation_date = operation_date
        if status is not None:
            self.status = status

    @property
    def amount(self):
        """Gets the amount of this PaymentCODI.  # noqa: E501

        Monto del pago  # noqa: E501

        :return: The amount of this PaymentCODI.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentCODI.

        Monto del pago  # noqa: E501

        :param amount: The amount of this PaymentCODI.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def description(self):
        """Gets the description of this PaymentCODI.  # noqa: E501

        Descripción del pago  # noqa: E501

        :return: The description of this PaymentCODI.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentCODI.

        Descripción del pago  # noqa: E501

        :param description: The description of this PaymentCODI.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def error_message(self):
        """Gets the error_message of this PaymentCODI.  # noqa: E501

        Mensaje de error  # noqa: E501

        :return: The error_message of this PaymentCODI.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this PaymentCODI.

        Mensaje de error  # noqa: E501

        :param error_message: The error_message of this PaymentCODI.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def id(self):
        """Gets the id of this PaymentCODI.  # noqa: E501

        Identificador del pago  # noqa: E501

        :return: The id of this PaymentCODI.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentCODI.

        Identificador del pago  # noqa: E501

        :param id: The id of this PaymentCODI.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def operation_date(self):
        """Gets the operation_date of this PaymentCODI.  # noqa: E501

        Fecha en que se efectuo el pago  # noqa: E501

        :return: The operation_date of this PaymentCODI.  # noqa: E501
        :rtype: datetime
        """
        return self._operation_date

    @operation_date.setter
    def operation_date(self, operation_date):
        """Sets the operation_date of this PaymentCODI.

        Fecha en que se efectuo el pago  # noqa: E501

        :param operation_date: The operation_date of this PaymentCODI.  # noqa: E501
        :type: datetime
        """

        self._operation_date = operation_date

    @property
    def status(self):
        """Gets the status of this PaymentCODI.  # noqa: E501

        Estatus del pago  # noqa: E501

        :return: The status of this PaymentCODI.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PaymentCODI.

        Estatus del pago  # noqa: E501

        :param status: The status of this PaymentCODI.  # noqa: E501
        :type: str
        """
        allowed_values = ["RECEIVED", "COMPLETED", "CANCELLED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentCODI, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentCODI):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.payment import Payment  # noqa: F401,E501


class PaymentsRequestId(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'authorization_date': 'datetime',
        'request_date': 'datetime',
        'request_id': 'str',
        'total_amount': 'float',
        'total_transactions': 'int',
        'transactions': 'list[Payment]'
    }

    attribute_map = {
        'authorization_date': 'authorization_date',
        'request_date': 'request_date',
        'request_id': 'request_id',
        'total_amount': 'total_amount',
        'total_transactions': 'total_transactions',
        'transactions': 'transactions'
    }

    def __init__(self, authorization_date=None, request_date=None, request_id=None, total_amount=None, total_transactions=None, transactions=None):  # noqa: E501
        """PaymentsRequestId - a model defined in Swagger"""  # noqa: E501
        self._authorization_date = None
        self._request_date = None
        self._request_id = None
        self._total_amount = None
        self._total_transactions = None
        self._transactions = None
        self.discriminator = None
        if authorization_date is not None:
            self.authorization_date = authorization_date
        if request_date is not None:
            self.request_date = request_date
        if request_id is not None:
            self.request_id = request_id
        if total_amount is not None:
            self.total_amount = total_amount
        if total_transactions is not None:
            self.total_transactions = total_transactions
        if transactions is not None:
            self.transactions = transactions

    @property
    def authorization_date(self):
        """Gets the authorization_date of this PaymentsRequestId.  # noqa: E501

        Fecha en que el usuario propietario del token emitió la autorización  # noqa: E501

        :return: The authorization_date of this PaymentsRequestId.  # noqa: E501
        :rtype: datetime
        """
        return self._authorization_date

    @authorization_date.setter
    def authorization_date(self, authorization_date):
        """Sets the authorization_date of this PaymentsRequestId.

        Fecha en que el usuario propietario del token emitió la autorización  # noqa: E501

        :param authorization_date: The authorization_date of this PaymentsRequestId.  # noqa: E501
        :type: datetime
        """

        self._authorization_date = authorization_date

    @property
    def request_date(self):
        """Gets the request_date of this PaymentsRequestId.  # noqa: E501

        Fecha en que se realizó la petición de registro de transacciones  # noqa: E501

        :return: The request_date of this PaymentsRequestId.  # noqa: E501
        :rtype: datetime
        """
        return self._request_date

    @request_date.setter
    def request_date(self, request_date):
        """Sets the request_date of this PaymentsRequestId.

        Fecha en que se realizó la petición de registro de transacciones  # noqa: E501

        :param request_date: The request_date of this PaymentsRequestId.  # noqa: E501
        :type: datetime
        """

        self._request_date = request_date

    @property
    def request_id(self):
        """Gets the request_id of this PaymentsRequestId.  # noqa: E501

        Identificador de la petición del registro de transacciones  # noqa: E501

        :return: The request_id of this PaymentsRequestId.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this PaymentsRequestId.

        Identificador de la petición del registro de transacciones  # noqa: E501

        :param request_id: The request_id of this PaymentsRequestId.  # noqa: E501
        :type: str
        """

        self._request_id = request_id

    @property
    def total_amount(self):
        """Gets the total_amount of this PaymentsRequestId.  # noqa: E501

        Monto total de las transacciones registradas  # noqa: E501

        :return: The total_amount of this PaymentsRequestId.  # noqa: E501
        :rtype: float
        """
        return self._total_amount

    @total_amount.setter
    def total_amount(self, total_amount):
        """Sets the total_amount of this PaymentsRequestId.

        Monto total de las transacciones registradas  # noqa: E501

        :param total_amount: The total_amount of this PaymentsRequestId.  # noqa: E501
        :type: float
        """

        self._total_amount = total_amount

    @property
    def total_transactions(self):
        """Gets the total_transactions of this PaymentsRequestId.  # noqa: E501

        Total de transacciones en la petición  # noqa: E501

        :return: The total_transactions of this PaymentsRequestId.  # noqa: E501
        :rtype: int
        """
        return self._total_transactions

    @total_transactions.setter
    def total_transactions(self, total_transactions):
        """Sets the total_transactions of this PaymentsRequestId.

        Total de transacciones en la petición  # noqa: E501

        :param total_transactions: The total_transactions of this PaymentsRequestId.  # noqa: E501
        :type: int
        """

        self._total_transactions = total_transactions

    @property
    def transactions(self):
        """Gets the transactions of this PaymentsRequestId.  # noqa: E501

        Lista de las transacciones registradas  # noqa: E501

        :return: The transactions of this PaymentsRequestId.  # noqa: E501
        :rtype: list[Payment]
        """
        return self._transactions

    @transactions.setter
    def transactions(self, transactions):
        """Sets the transactions of this PaymentsRequestId.

        Lista de las transacciones registradas  # noqa: E501

        :param transactions: The transactions of this PaymentsRequestId.  # noqa: E501
        :type: list[Payment]
        """

        self._transactions = transactions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentsRequestId, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentsRequestId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from wire4_client.models.codi_operation_response_dto import CodiOperationResponseDTO  # noqa: F401,E501


class PaymentRequestCodiResponseDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'float',
        'barcode_base64': 'str',
        'barcode_url': 'str',
        'concept': 'str',
        'creation_date': 'datetime',
        'due_date': 'datetime',
        'operations': 'list[CodiOperationResponseDTO]',
        'order_id': 'str',
        'phone_number': 'str',
        'status': 'str',
        'type': 'str'
    }

    attribute_map = {
        'amount': 'amount',
        'barcode_base64': 'barcode_base64',
        'barcode_url': 'barcode_url',
        'concept': 'concept',
        'creation_date': 'creation_date',
        'due_date': 'due_date',
        'operations': 'operations',
        'order_id': 'order_id',
        'phone_number': 'phone_number',
        'status': 'status',
        'type': 'type'
    }

    def __init__(self, amount=None, barcode_base64=None, barcode_url=None, concept=None, creation_date=None, due_date=None, operations=None, order_id=None, phone_number=None, status=None, type=None):  # noqa: E501
        """PaymentRequestCodiResponseDTO - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._barcode_base64 = None
        self._barcode_url = None
        self._concept = None
        self._creation_date = None
        self._due_date = None
        self._operations = None
        self._order_id = None
        self._phone_number = None
        self._status = None
        self._type = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if barcode_base64 is not None:
            self.barcode_base64 = barcode_base64
        if barcode_url is not None:
            self.barcode_url = barcode_url
        if concept is not None:
            self.concept = concept
        if creation_date is not None:
            self.creation_date = creation_date
        if due_date is not None:
            self.due_date = due_date
        if operations is not None:
            self.operations = operations
        if order_id is not None:
            self.order_id = order_id
        if phone_number is not None:
            self.phone_number = phone_number
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type

    @property
    def amount(self):
        """Gets the amount of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es el Monto del pago. Ejemplo 1000.00  # noqa: E501

        :return: The amount of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentRequestCodiResponseDTO.

        Es el Monto del pago. Ejemplo 1000.00  # noqa: E501

        :param amount: The amount of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def barcode_base64(self):
        """Gets the barcode_base64 of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es la imagen QR en formato Base64 para el CODI®.  # noqa: E501

        :return: The barcode_base64 of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._barcode_base64

    @barcode_base64.setter
    def barcode_base64(self, barcode_base64):
        """Sets the barcode_base64 of this PaymentRequestCodiResponseDTO.

        Es la imagen QR en formato Base64 para el CODI®.  # noqa: E501

        :param barcode_base64: The barcode_base64 of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: str
        """

        self._barcode_base64 = barcode_base64

    @property
    def barcode_url(self):
        """Gets the barcode_url of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es la dirección URL de la imagen QR para el CODI®.  # noqa: E501

        :return: The barcode_url of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._barcode_url

    @barcode_url.setter
    def barcode_url(self, barcode_url):
        """Sets the barcode_url of this PaymentRequestCodiResponseDTO.

        Es la dirección URL de la imagen QR para el CODI®.  # noqa: E501

        :param barcode_url: The barcode_url of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: str
        """

        self._barcode_url = barcode_url

    @property
    def concept(self):
        """Gets the concept of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es el concepto de pago.  # noqa: E501

        :return: The concept of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._concept

    @concept.setter
    def concept(self, concept):
        """Sets the concept of this PaymentRequestCodiResponseDTO.

        Es el concepto de pago.  # noqa: E501

        :param concept: The concept of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: str
        """

        self._concept = concept

    @property
    def creation_date(self):
        """Gets the creation_date of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es la fecha de creación. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The creation_date of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this PaymentRequestCodiResponseDTO.

        Es la fecha de creación. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param creation_date: The creation_date of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: datetime
        """

        self._creation_date = creation_date

    @property
    def due_date(self):
        """Gets the due_date of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es la fecha de vencimiento. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :return: The due_date of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this PaymentRequestCodiResponseDTO.

        Es la fecha de vencimiento. Ésta fecha viene en formato ISO 8601 con zona horaria, ejemplo: <strong>2020-10-27T11:03:15.000-06:00</strong>.  # noqa: E501

        :param due_date: The due_date of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: datetime
        """

        self._due_date = due_date

    @property
    def operations(self):
        """Gets the operations of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es el listado de pagos realizados sobre la petición.  # noqa: E501

        :return: The operations of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: list[CodiOperationResponseDTO]
        """
        return self._operations

    @operations.setter
    def operations(self, operations):
        """Sets the operations of this PaymentRequestCodiResponseDTO.

        Es el listado de pagos realizados sobre la petición.  # noqa: E501

        :param operations: The operations of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: list[CodiOperationResponseDTO]
        """

        self._operations = operations

    @property
    def order_id(self):
        """Gets the order_id of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es el orderId asignado a la solicitud.  # noqa: E501

        :return: The order_id of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this PaymentRequestCodiResponseDTO.

        Es el orderId asignado a la solicitud.  # noqa: E501

        :param order_id: The order_id of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: str
        """

        self._order_id = order_id

    @property
    def phone_number(self):
        """Gets the phone_number of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es el número de teléfono.  # noqa: E501

        :return: The phone_number of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PaymentRequestCodiResponseDTO.

        Es el número de teléfono.  # noqa: E501

        :param phone_number: The phone_number of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def status(self):
        """Gets the status of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es el estado (estatus) de la orden de pago. Los valores pueden ser: <b>RECEIVED, COMPLETED Y CANCELLED</b>  # noqa: E501

        :return: The status of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PaymentRequestCodiResponseDTO.

        Es el estado (estatus) de la orden de pago. Los valores pueden ser: <b>RECEIVED, COMPLETED Y CANCELLED</b>  # noqa: E501

        :param status: The status of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def type(self):
        """Gets the type of this PaymentRequestCodiResponseDTO.  # noqa: E501

        Es el tipo de petición. Los valores pueden ser: <b>QR_CODE o PUSH_NOTIFICATION</b>  # noqa: E501

        :return: The type of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PaymentRequestCodiResponseDTO.

        Es el tipo de petición. Los valores pueden ser: <b>QR_CODE o PUSH_NOTIFICATION</b>  # noqa: E501

        :param type: The type of this PaymentRequestCodiResponseDTO.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentRequestCodiResponseDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentRequestCodiResponseDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Wire4RestAPI

    Referencia de la API de Wire4  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import wire4_client
from api.contacto_api import ContactoApi  # noqa: E501
from wire4_client.rest import ApiException


class TestContactoApi(unittest.TestCase):
    """ContactoApi unit test stubs"""

    def setUp(self):
        self.api = api.contacto_api.ContactoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_send_contact_using_post(self):
        """Test case for send_contact_using_post

        Solicitud de contacto  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
